@@ -1,4 +1,5 @@
 from django.core import urlresolvers
+from django.core.exceptions import ImproperlyConfigured
 from django.utils.translation import ugettext_lazy as _
 
 __all__ = ('AutocompleteInterface', 'AutocompleteBase')
@@ -57,8 +58,16 @@ class AutocompleteInterface(object):
         Return the absolute url for this autocomplete, using
         autocomplete_light_autocomplete url
         """
-        return urlresolvers.reverse('autocomplete_light_autocomplete', args=(
-            self.__class__.__name__,))
+        try:
+            return urlresolvers.reverse('autocomplete_light_autocomplete', args=(
+                self.__class__.__name__,))
+        except urlresolvers.NoReverseMatch, e:
+            # Such error will ruin form rendering. It would be automatically
+            # silenced because of e.silent_variable_failure=True, which is
+            # something we don't want. Let's give the user a hint:
+            raise ImproperlyConfigured("URL lookup for autocomplete '%s' "
+                    "failed. Have you included autocomplete_light.urls in "
+                    "your urls.py?" % (self.__class__.__name__,))
 
 
 class AutocompleteBase(AutocompleteInterface):
